ezpickle
========================

Helper functions to simplify pickling and unpickling objects to/from files.
- ***pickle_data**(data, filepath: Path | str, overwrite: bool = False)* : Pickle an object (such as a dictionary) and write it to a file
- ***unpickle_data**(filepath: Path | str, dict_keys: str | Iterable | None = None)* : Load a pickled object from a file


Releases
--------

1.0, 2021-10-26
* Initial release


License
-------

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.
